------
-- Written by: Hugh@Burning Blade-US and Simca@Malfurion-US
------
-- Special thanks to Nullberri, Ro, and Warla for helping at various points throughout the addon's development
------
-- GLOBALS: BPBID_Options, GetBreedID_Battle, GetBreedID_Journal, SLASH_BATTLEPETBREEDID1, SLASH_BATTLEPETBREEDID2, SLASH_BATTLEPETBREEDID3

-- get folder path and set addon namespace
local addonname, BPBID = ...

-- these global tables are used everywhere in the code and are absolutely required
local CPB = _G.C_PetBattles
local CPJ = _G.C_PetJournal

-- these basic lua functions are used in the calculating of breed IDs and must be localized due to the number and frequency of uses
local min = math.min
local abs = math.abs
local floor = math.floor

-- these basic lua functions are used for Retrieving Breed Names
-- they're only used once but still important to localize due to the time sensitive nature of the task
local tostring = tostring
local tonumber = tonumber
local sub = string.sub

-- declare addon-wide arrays
local BasePetStats = {}
local BreedStats = {}
local BreedsPerSpecies = {}

-- declare local cache variables
local breedCache = {}
local speciesCache = {}
local cacheTime = true
local arraysInitialized = false

-- takes in lots of information, returns Breed ID as a number (or an error), and the rarity as a number
local function BPBID_CalculateBreedID(nSpeciesID, nQuality, nLevel, nMaxHP, nPower, nSpeed, wild, flying)
	
	-- arrays are now initialized
	if (not arraysInitialized) then BPBID.InitializeArrays() end
	
	local breedID, nQL, minQuality, maxQuality
	
	-- due to a Blizzard bug, some pets from tooltips will have quality = 0. this means we don't know what the quality is.
	-- so, we'll just test them all by adding another loop for rarity.
	if nQuality == 0 then
		minQuality = 1
		maxQuality = 4
	else
		minQuality = nQuality
		maxQuality = nQuality
	end
	
	-- prevent "nil" errors if species is new to the game
	if not BasePetStats[nSpeciesID] then return "NEW" end
	
	-- Simca v0.8 comment: I've removed my method of calculating BreedIDs now that I've added an an array of all breeds
	-- and logic on how to distiniguish between identical breeds.
	
	-- localize base species stats and upconvert to avoid floating point errors
	local ihp = BasePetStats[nSpeciesID][1] * 10
	local ipower = BasePetStats[nSpeciesID][2] * 10
	local ispeed = BasePetStats[nSpeciesID][3] * 10
	
	-- account for wild pet hp
	local wildfactor = 1
	if wild then wildfactor = 1.2 end
	
	-- upconvert to avoid floating point errors
	local thp = nMaxHP * 100
	local tpower = nPower * 100
	local tspeed = nSpeed * 100
	
	-- account for flying pet passive
	if flying then tspeed = tspeed / 1.5 end
	
	local lowest
	for i = minQuality, maxQuality do
		nQL = (i + 9) * nLevel
		
		-- higher level pets can never have duplicate breeds, so calculations can be less accurate and faster (they remain the same since version 0.7)
		if (nLevel > 5) then
		
			-- calculate diffs
			local diff3 = abs(((ihp + 5) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 5) * nQL) - tpower) + abs(((ispeed + 5) * nQL) - tspeed)
			local diff4 = abs((ihp * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 20) * nQL) - tpower) + abs((ispeed * nQL) - tspeed)
			local diff5 = abs((ihp * nQL * 5 + 10000) / wildfactor - thp) + abs((ipower * nQL) - tpower) + abs(((ispeed + 20) * nQL) - tspeed)
			local diff6 = abs(((ihp + 20) * nQL * 5 + 10000) / wildfactor - thp) + abs((ipower * nQL) - tpower) + abs((ispeed * nQL) - tspeed)
			local diff7 = abs(((ihp + 9) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 9) * nQL) - tpower) + abs((ispeed * nQL) - tspeed)
			local diff8 = abs((ihp * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 9) * nQL) - tpower) + abs(((ispeed + 9) * nQL) - tspeed)
			local diff9 = abs(((ihp + 9) * nQL * 5 + 10000) / wildfactor - thp) + abs((ipower * nQL) - tpower) + abs(((ispeed + 9) * nQL) - tspeed)
			local diff10 = abs(((ihp + 4) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 9) * nQL) - tpower) + abs(((ispeed + 4) * nQL) - tspeed)
			local diff11 = abs(((ihp + 4) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 4) * nQL) - tpower) + abs(((ispeed + 9) * nQL) - tspeed)
			local diff12 = abs(((ihp + 9) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 4) * nQL) - tpower) + abs(((ispeed + 4) * nQL) - tspeed)
			
			-- calculate min diff
			local current = min(diff3, diff4, diff5, diff6, diff7, diff8, diff9, diff10, diff11, diff12)
			
			if not lowest or current < lowest then
				lowest = current
				nQuality = i
				
				-- determine breed from min diff
				if (lowest == diff3) then breedID = 3
				elseif (lowest == diff4) then breedID = 4
				elseif (lowest == diff5) then breedID = 5
				elseif (lowest == diff6) then breedID = 6
				elseif (lowest == diff7) then breedID = 7
				elseif (lowest == diff8) then breedID = 8
				elseif (lowest == diff9) then breedID = 9
				elseif (lowest == diff10) then breedID = 10
				elseif (lowest == diff11) then breedID = 11
				elseif (lowest == diff12) then breedID = 12
				else return "ERR-MIN" -- return error if breed determination fails (impossible?)
				end
			end
		
		-- lowbie pets go here, the bane of my existance. calculations must be intense and logic loops numerous
		else
			
			-- calculate diffs much more intensely. Round calculations with 10^-2 and math.floor. Also, properly devalue HP by dividing its absolute value by 5
			local diff3 = (abs((floor(((ihp + 5) * nQL * 5 + 10000) / wildfactor * 0.01 + 0.5) / 0.01) - thp) / 5) + abs((floor( ((ipower + 5) * nQL) * 0.01 + 0.5) / 0.01) - tpower) + abs((floor( ((ispeed + 5) * nQL) * 0.01 + 0.5) / 0.01) - tspeed)
			local diff4 = (abs((floor((ihp * nQL * 5 + 10000) / wildfactor * 0.01 + 0.5) / 0.01) - thp) / 5) + abs((floor( ((ipower + 20) * nQL) * 0.01 + 0.5) / 0.01) - tpower) + abs((floor( (ispeed * nQL) * 0.01 + 0.5) / 0.01) - tspeed)
			local diff5 = (abs((floor((ihp * nQL * 5 + 10000) / wildfactor * 0.01 + 0.5) / 0.01) - thp) / 5) + abs((floor( (ipower * nQL) * 0.01 + 0.5) / 0.01) - tpower) + abs((floor( ((ispeed + 20) * nQL) * 0.01 + 0.5) / 0.01) - tspeed)
			local diff6 = (abs((floor(((ihp + 20) * nQL * 5 + 10000) / wildfactor * 0.01 + 0.5) / 0.01) - thp) / 5) + abs((floor( (ipower * nQL) * 0.01 + 0.5) / 0.01) - tpower) + abs((floor( (ispeed * nQL) * 0.01 + 0.5) / 0.01) - tspeed)
			local diff7 = (abs((floor(((ihp + 9) * nQL * 5 + 10000) / wildfactor * 0.01 + 0.5) / 0.01) - thp) / 5) + abs((floor( ((ipower + 9) * nQL) * 0.01 + 0.5) / 0.01) - tpower) + abs((floor( (ispeed * nQL) * 0.01 + 0.5) / 0.01) - tspeed)
			local diff8 = (abs((floor((ihp * nQL * 5 + 10000) / wildfactor * 0.01 + 0.5) / 0.01) - thp) / 5) + abs((floor( ((ipower + 9) * nQL) * 0.01 + 0.5) / 0.01) - tpower) + abs((floor( ((ispeed + 9) * nQL) * 0.01 + 0.5) / 0.01) - tspeed)
			local diff9 = (abs((floor(((ihp + 9) * nQL * 5 + 10000) / wildfactor * 0.01 + 0.5) / 0.01) - thp) / 5) + abs((floor( (ipower * nQL) * 0.01 + 0.5) / 0.01) - tpower) + abs((floor( ((ispeed + 9) * nQL) * 0.01 + 0.5) / 0.01) - tspeed)
			local diff10 = (abs((floor(((ihp + 4) * nQL * 5 + 10000) / wildfactor * 0.01 + 0.5) / 0.01) - thp) / 5) + abs((floor( ((ipower + 9) * nQL) * 0.01 + 0.5) / 0.01) - tpower) + abs((floor( ((ispeed + 4) * nQL) * 0.01 + 0.5) / 0.01) - tspeed)
			local diff11 = (abs((floor(((ihp + 4) * nQL * 5 + 10000) / wildfactor * 0.01 + 0.5) / 0.01) - thp) / 5) + abs((floor( ((ipower + 4) * nQL) * 0.01 + 0.5) / 0.01) - tpower) + abs((floor( ((ispeed + 9) * nQL) * 0.01 + 0.5) / 0.01) - tspeed)
			local diff12 = (abs((floor(((ihp + 9) * nQL * 5 + 10000) / wildfactor * 0.01 + 0.5) / 0.01) - thp) / 5) + abs((floor( ((ipower + 4) * nQL) * 0.01 + 0.5) / 0.01) - tpower) + abs((floor( ((ispeed + 4) * nQL) * 0.01 + 0.5) / 0.01) - tspeed)
			
			-- use custom replacement code for math.min to find duplicate breed possibilities
			local numberlist = { diff3, diff4, diff5, diff6, diff7, diff8, diff9, diff10, diff11, diff12 }
			local secondnumberlist = {}
			local resultslist = {}
			local numResults = 0
			local smallest
			
			-- if we know the breeds for species, use this series of logic statements to eliminate impossible breeds
			if BreedsPerSpecies[nSpeciesID] then
				
				-- this half of the table stores the diffs for the breeds that passed inspection 
				secondnumberlist[1] = {}
				-- this half of the table stores the number corresponding to the breeds that passed inspection since we can no longer rely on the index
				secondnumberlist[2] = {}
				
				-- "inspection" time! if the breed is not found in the array, it doesn't get passed on to secondnumberlist and is effectively discarded
				for i = 1, #BreedsPerSpecies[nSpeciesID] do
					local currentbreed = BreedsPerSpecies[nSpeciesID][i]
					-- subtracting 2 from the breed to use it as an index (scale of 3-13 becomes 1-10)
					secondnumberlist[1][i] = numberlist[currentbreed - 2]
					secondnumberlist[2][i] = currentbreed
				end
				
				-- find the smallest number out of the breeds left
				for i = 1, #secondnumberlist[2] do
					-- if this breed is the closest to perfect we've seen, make it our only result (destroy all other results)
					if (not smallest) or (secondnumberlist[1][i] < smallest) then 
						smallest = secondnumberlist[1][i]
						numResults = 1
						resultslist = {}
						resultslist[1] = secondnumberlist[2][i]
					-- if we find a duplicate, add it to the list (but it can still be destroyed if better is found)
					elseif (secondnumberlist[1][i] == smallest) then
						numResults = numResults + 1
						resultslist[numResults] = secondnumberlist[2][i]
					end
				end
			
			-- if we don't know the species, use this series of logic statements to consider all possibilities
			else
				-- iterate over all entries in 
				for i = 1, #numberlist do
					-- if this breed is the closest to perfect we've seen, make it our only result (destroy all other results)
					if (not smallest) or (numberlist[i] < smallest) then 
						smallest = numberlist[i]
						numResults = 1
						resultslist = {}
						resultslist[1] = i + 2
					-- if we find a duplicate, add it to the list (but it can still be destroyed if better is found)
					elseif (numberlist[i] == smallest) then
						numResults = numResults + 1
						resultslist[numResults] = i + 2
					end
				end
			end
			
			-- check to see if this is the smallest value reported out of all qualities (or if the quality is not in question)
			if not lowest or smallest < lowest then
				lowest = smallest
				nQuality = i
				
				-- set breedID to best suited breed (or ??? if matching breeds) (or ERR-BMN if error)
				if resultslist[2] then
					breedID = "???"
				elseif resultslist[1] then
					breedID = resultslist[1]
				else
					breedID = "ERR-BMN"
				end
				
				-- if something is perfectly accuracte after already checking all the others of that quality, there is no need to continue (obviously)
				if (smallest == 0) then break end
			end
		end
	end
	
	-- return breed (or error)
	if breedID then
		return breedID, nQuality
	else
		return "ERR-CAL"
	end
end

-- match breedID to name, second number, double letter code (S/S), entire base+breed stats, or just base stats
local function BPBID_RetrieveBreedName(breedID, species)
	-- exit if no breedID found
	if not breedID then return "ERR-ELY" end -- should be impossible now
	
	-- exit if error message found
	if (sub(tostring(breedID), 1, 3) == "ERR") or (tostring(breedID) == "???") or (tostring(breedID) == "NEW") then return breedID end
	
	local numbreedID = tonumber(breedID)
	local result = {}
	
	if (BPBID_Options.format == 1) then -- return single number
		return numbreedID	
	elseif (BPBID_Options.format == 5) and (species) then -- return entire base+breed stats
		result[4] = tostring(BasePetStats[species][1] + BreedStats[numbreedID][1]) .. "/" .. tostring(BasePetStats[species][2] + BreedStats[numbreedID][2]) .. "/" .. tostring(BasePetStats[species][3] + BreedStats[numbreedID][3])
		return result[4]
	elseif (BPBID_Options.format == 6) and (species) then -- return base stats only (nothing to do with breed, but still, we're the only ones with species stats too)
		result[5] = tostring(BasePetStats[species][1]) .. "/" .. tostring(BasePetStats[species][2]) .. "/" .. tostring(BasePetStats[species][3])
		return result[5]
	end
	
	if (numbreedID == 3) then
		result[1] = "3/13"
		result[2] = "B/B"
	elseif (numbreedID == 4) then
		result[1] = "4/14"
		result[2] = "P/P"
	elseif (numbreedID == 5) then
		result[1] = "5/15"
		result[2] = "S/S"
	elseif (numbreedID == 6) then
		result[1] = "6/16"
		result[2] = "H/H"
	elseif (numbreedID == 7) then
		result[1] = "7/17"
		result[2] = "H/P"
	elseif (numbreedID == 8) then
		result[1] = "8/18"
		result[2] = "P/S"
	elseif (numbreedID == 9) then
		result[1] = "9/19"
		result[2] = "H/S"
	elseif (numbreedID == 10) then
		result[1] = "10/20"
		result[2] = "P/B"
	elseif (numbreedID == 11) then
		result[1] = "11/21"
		result[2] = "S/B"
	elseif (numbreedID == 12) then
		result[1] = "12/22"
		result[2] = "H/B"
	else
		result[1] = "ERR-NAM"
		result[2] = "ERR-NAM"
	end
	
	if (BPBID_Options.format == 2) then -- 2 = doublenumber
		return result[1]
	elseif (BPBID_Options.format == 3) then -- 3 = double letter
		return result[2]
	else -- this should never happen, but single number just in case it does
		return numbreedID
	end
end

-- get information from pet journal and pass to calculation function
function GetBreedID_Journal(nPetID)
	local nbreedID = ""
	if (nPetID) then
		-- get information from pet journal
		local nHealth, nMaxHP, nPower, nSpeed, nQuality = CPJ.GetPetStats(nPetID)
		local nSpeciesID, _, nLevel = CPJ.GetPetInfoByPetID(nPetID);
		
		-- pass to calculation function and then retrieve breed name
		nbreedID = BPBID_RetrieveBreedName(BPBID_CalculateBreedID(nSpeciesID, nQuality, nLevel, nMaxHP, nPower, nSpeed, false, false), nSpeciesID)
	else
		nbreedID = "ERR-PID"
	end
	
	return nbreedID
end

-- retrieve pre-determined Breed ID from cache for pet being moused over
function GetBreedID_Battle(self)
	local nbreedID
	
	if (self) then
		-- determine index of BreedCache array. accepted values are 1-6 with 1-3 being your pets and 4-6 being enemy pets
		local offset = 0
		if (self.petOwner == 2) then offset = 3 end
		
		-- get name for cached breedID/speciesID
		nbreedID = BPBID_RetrieveBreedName(breedCache[self.petIndex + offset], speciesCache[self.petIndex + offset])
	else
		nbreedID = "ERR_SLF"
	end
	
	return nbreedID
end

-- get pet stats and breed at the start of battle before values change
local function BPBID_CacheAllPets()
	for iOwner = 1, 2 do
		local IndexMax = CPB.GetNumPets(iOwner)
		for iIndex = 1, IndexMax do
			local nSpeciesID = CPB.GetPetSpeciesID(iOwner, iIndex)
			local nLevel = CPB.GetLevel(iOwner, iIndex)
			local nMaxHP = CPB.GetMaxHealth(iOwner, iIndex)
			local nPower = CPB.GetPower(iOwner, iIndex)
			local nSpeed = CPB.GetSpeed(iOwner, iIndex)
			local nQuality = CPB.GetBreedQuality(iOwner, iIndex)
			local wild = false
			local flying = false
			
			-- if pet is wild, add 20% hp to get the normal stat
			if (CPB.IsWildBattle() and iOwner == 2) then wild = true end
			
			-- still have to account for flying passive apparently; can't get the stats snapshot before passive is applied
			if (CPB.GetPetType(iOwner, iIndex) == 3) then
				if (iOwner == 1) and ((CPB.GetHealth(iOwner, iIndex) / nMaxHP) > .5) then
					flying = true
				elseif (iOwner == 2) then
					flying = true
				end
			end
			
			-- determine index of Cache arrays. accepted values are 1-6 with 1-3 being your pets and 4-6 being enemy pets
			local offset = 0
			if (iOwner == 2) then offset = 3 end
			
			-- calculate breedID and store it in cache along with speciesID
			breedCache[iIndex + offset] = BPBID_CalculateBreedID(nSpeciesID, nQuality, nLevel, nMaxHP, nPower, nSpeed, wild, flying)
			speciesCache[iIndex + offset] = nSpeciesID
		end
	end
end

-- add breedIDs to pet frames in Pet Battles
local function BPBID_Hook_BattleUpdate(self)
	if not self.petOwner or not self.petIndex then return end
	
	if (cacheTime == true) then BPBID_CacheAllPets() end
	
	if self.Name then
		local name = CPB.GetName(self.petOwner, self.petIndex)
		if name then self.Name:SetText(name.." ("..GetBreedID_Battle(self)..")") end
	end
	
	cacheTime = false
end

-- display breed on PetJournal's ScrollFrame
local function BPBID_Hook_HSFUpdate(scrollFrame)
	if scrollFrame == PetJournalListScrollFrame then
		if not PetJournal:IsShown() then return end
		
		local buttonName, label, labelName, petID
		for i = 1, #scrollFrame.buttons do
			local thisPet = scrollFrame.buttons[i]
			local petID = thisPet.petID
			if petID ~= nil then
				local _, customName, _, _, _, _, _, name = CPJ.GetPetInfoByPetID(petID)
				if name then
					local _, _, _, _, rarity = CPJ.GetPetStats(petID)
					local _, _, _, hex = GetItemQualityColor(rarity - 1)
					
					-- display breed as part of the nickname if the pet has one, otherwise use the real name
					if customName then
						thisPet.name:SetText("|c"..hex..customName.." ("..GetBreedID_Journal(petID)..")".."|r")
						thisPet.subName:Show()
						thisPet.subName:SetText(name)
					else
						thisPet.name:SetText("|c"..hex..name.." ("..GetBreedID_Journal(petID)..")".."|r")
						thisPet.subName:Hide()
					end
					
					-- downside font if the name/breed gets chopped off
					if thisPet.name:IsTruncated() then
						thisPet.name:SetFontObject("GameFontNormalSmall")
					else
						thisPet.name:SetFontObject("GameFontNormal")
					end
				end
			end
		end
	end
end

-- display breed and quality if necessary on pet tooltips from chat links
local function BPBID_Hook_FBPTShow(speciesID, level, rarity, maxHealth, power, speed, name)
	rarity = rarity + 1
	local breedNum, quality = BPBID_CalculateBreedID(speciesID, rarity, level, maxHealth, power, speed, false, false)
	local breed = BPBID_RetrieveBreedName(breedNum, speciesID)
	
	local FBPT = _G["FloatingBattlePetTooltip"]

	FBPT.Name:SetText(name.." ("..breed..")");
	if rarity == 0 then
		FBPT.Name:SetVertexColor(ITEM_QUALITY_COLORS[quality-1].r, ITEM_QUALITY_COLORS[quality-1].g, ITEM_QUALITY_COLORS[quality-1].b);
	end
	
	local stringwide = FBPT.Name:GetStringWidth() + 14
	if stringwide < 238 then stringwide = 238 end
	
	-- could potentially try to avoid collisons better here but it will be hard because these aren't even really GameTooltips
	-- resize all relevant parts of tooltip to avoid cutoff breeds/names (since Blizzard made these static-sized!)
	-- however, no known AddOn conflicts with this tooltip for now (it's going to be BPTShow that we have to worry about)
	FBPT:SetWidth(stringwide + 22)
	FBPT.Name:SetWidth(stringwide)
	FBPT.BattlePet:SetWidth(stringwide)
	--FBPT.PetType:SetWidth(stringwide) not needed right now apparently
	FBPT.Level:SetWidth(stringwide)
	--FBPT.Owned:SetWidth(stringwide) not needed right now apparently
	FBPT.Delimiter:SetWidth(stringwide + 13)
	FBPT.JournalClick:SetWidth(stringwide)
end

-- display breed and quality if necessary on item-based pet tooltips
local function BPBID_Hook_BPTShow(speciesID, level, rarity, maxHealth, power, speed, name)
	rarity = rarity + 1
	local breedNum, quality = BPBID_CalculateBreedID(speciesID, rarity, level, maxHealth, power, speed, false, false)
	local breed = BPBID_RetrieveBreedName(breedNum, speciesID)
	
	local BPT = _G["BattlePetTooltip"]
	
	-- addon conflicts cause chaos when trying real solutions (like resizing tooltip)
	-- at least I can still change the !@#$ font without them running home to cry about it
	-- it fixes the cutoff issue, but it isn't pretty.
	BPT.Name:SetFontObject("GameFontNormalLargeLeft")
	BPT.Name:SetHeight(0)
	BPT.Name:SetText(name.." ("..breed..")");
	
	if (BPT.Name:IsTruncated()) then
		BPT.Name:SetFontObject("GameFontNormalLeft")
		BPT.Name:SetHeight(16)
	end
	
	if (rarity == 0) or (changedfont) then
		BPT.Name:SetVertexColor(ITEM_QUALITY_COLORS[quality-1].r, ITEM_QUALITY_COLORS[quality-1].g, ITEM_QUALITY_COLORS[quality-1].b);
	end
end

-- create event handling frame and register event(s)
local BPBID_Events = CreateFrame("FRAME", "BPBID_Events")
BPBID_Events:RegisterEvent("ADDON_LOADED")
BPBID_Events:RegisterEvent("PET_BATTLE_OPENING_START")
BPBID_Events:RegisterEvent("PET_BATTLE_CLOSE")

-- OnEvent handler function
local function BPBID_Events_OnEvent(self, event, ...)
	if (event == "ADDON_LOADED") and (... == addonname) then
		-- create saved variables if missing
		if (not BPBID_Options) then
			BPBID_Options = {}
		end
		if (not BPBID_Options.format) and (stridform) then
			BPBID_Options.format = stridform
		elseif (not BPBID_Options.format) then
			BPBID_Options.format = 3
		end
	elseif (event == "PET_BATTLE_OPENING_START") then
		cacheTime = true
	elseif (event == "PET_BATTLE_CLOSE") then
		cacheTime = true
	end
end

-- set our event handler function
BPBID_Events:SetScript("OnEvent", BPBID_Events_OnEvent)

-- hook our function into UpdateDisplay
hooksecurefunc("PetBattleUnitFrame_UpdateDisplay", BPBID_Hook_BattleUpdate)
hooksecurefunc("HybridScrollFrame_Update", BPBID_Hook_HSFUpdate)
hooksecurefunc("BattlePetToolTip_Show", BPBID_Hook_BPTShow)
hooksecurefunc("FloatingBattlePet_Show", BPBID_Hook_FBPTShow)

-- create slash commands
SLASH_BATTLEPETBREEDID1 = "/battlepetbreedID"
SLASH_BATTLEPETBREEDID2 = "/BPBID"
SLASH_BATTLEPETBREEDID3 = "/breedID"
SlashCmdList["BATTLEPETBREEDID"] = function(message) -- ALL IRRELEVANT SOON. OPTIONS MENU HERE WE COME!
	-- lowercase message for evaluation
	local msg = string.lower(message)
	
	-- create saved variable if missing
	if (not BPBID_Options.format) then
		BPBID_Options.format = 3
	end
	
	-- compare message against possible choices
	if (msg == "1") or (msg == "onenumber") or (msg == "one number") or (msg == "1 number") or (msg == "1#") then -- set it to only show one number
		BPBID_Options.format = 1
		print("Now displaying Breed IDs as a single number. Add 10 to the number to get the Breed ID if it were female (we can't tell from in-game yet - bug Blizzard!).")
	elseif (msg == "2") or (msg == "twonumber") or (msg == "two numbers") or (msg == "twonumbers") or (msg == "2 numbers") or (msg == "2numbers") then -- set it to show two numbers
		BPBID_Options.format = 2
		print("Now displaying Breed IDs as both of their possible numbers. The first listed number is the male breed and the second listed number is the female breed equivalent.")
	elseif (msg == "3") or (msg == "twoletter") or (msg == "two letter") or (msg == "two letters") or (msg == "twoletters") then -- set it to show two letters
		BPBID_Options.format = 3
		print("Now displaying Breed IDs as a pair of letters. Each letter represents an aspect of their breed. For example, P/P represents Breed 4, which is the highest Power build (has a double dose of Power). This is the default option.")
	elseif (msg == "5") or (msg == "allstats") or (msg == "all stats") or (msg == "breed and base stats") or (msg == "breedbasestats") or (msg == "breedandbasestats") then
		BPBID_Options.format = 5
		print("Now displaying Breed ID values combined with Base Species values. This allows you to see the stats of the pet as if it were a level 1 Poor. This allows for easy comparisons between pets of different levels and rarities, so you know what they could be like relative to each other if they were level 25 and Rare.")
	elseif (msg == "6") or (msg == "basestatsonly") or (msg == "base stats only") or (msg == "base stats") or (msg == "basestats") or (msg == "speciesstats") then
		BPBID_Options.format = 6
		print("Now not displaying Breed IDs. Instead, displaying Base Stats for each Species. This will allow you to see the stats of the pet as if it were a level 1 Poor with no breed. This is a useful mode for making comparisons between two different species of pet.")
	elseif (msg == "h") or (msg == "help") or (msg == "?") then -- help
		print("Available commands are 'onenumber', 'twonumber', 'twoletter' (this is the default setting), 'allstats', 'basestatsonly', and 'help'. Example: /breedID onenumber")
	else
		print("Invalid command! Available commands are 'onenumber', 'twonumbers', 'twoletters' (this is the default setting), 'allstats', 'basestatsonly', and 'help'. Example: /breedID onenumber")
	end
end

function BPBID.InitializeArrays()
	
	arraysInitialized = true
	
	-- fill breed array
	BreedStats[3] = {0.5, 0.5, 0.5}
	BreedStats[4] = {0, 2, 0}
	BreedStats[5] = {0, 0, 2}
	BreedStats[6] = {2, 0, 0}
	BreedStats[7] = {0.9, 0.9, 0}
	BreedStats[8] = {0, 0.9, 0.9}
	BreedStats[9] = {0.9, 0, 0.9}
	BreedStats[10] = {0.4, 0.9, 0.4}
	BreedStats[11] = {0.4, 0.4, 0.9}
	BreedStats[12] = {0.9, 0.4, 0.4}

	-- fill base stats array
	BasePetStats[39] = {8.5, 7.5, 8}
	BasePetStats[40] = {7, 8.5, 8.5}
	BasePetStats[41] = {7, 8.5, 8.5}
	BasePetStats[42] = {6.5, 9, 8.5}
	BasePetStats[43] = {7, 9, 8}
	BasePetStats[44] = {7, 8.5, 8.5}
	BasePetStats[45] = {7, 8.5, 8.5}
	BasePetStats[46] = {7.5, 7.5, 9}
	BasePetStats[47] = {8, 7.5, 8.5}
	BasePetStats[49] = {9, 7, 8}
	BasePetStats[50] = {9, 8, 7}
	BasePetStats[51] = {8.5, 8, 7.5}
	BasePetStats[52] = {8, 8, 8}
	BasePetStats[55] = {8.5, 7, 8.5}
	BasePetStats[56] = {8.5, 9, 6.5}
	BasePetStats[57] = {8.5, 7.5, 8}
	BasePetStats[58] = {7, 9, 8}
	BasePetStats[59] = {8.5, 8, 7.5}
	BasePetStats[64] = {8.5, 7.5, 8}
	BasePetStats[65] = {8.5, 7.5, 8}
	BasePetStats[67] = {8, 8, 8}
	BasePetStats[68] = {8, 8, 8}
	BasePetStats[69] = {7.5, 7.5, 9}
	BasePetStats[70] = {8, 7.5, 8.5}
	BasePetStats[71] = {8, 8, 8}
	BasePetStats[72] = {8, 7, 9}
	BasePetStats[73] = {8, 8, 8}
	BasePetStats[74] = {7.5, 7.5, 9}
	BasePetStats[75] = {7.5, 8.5, 8}
	BasePetStats[77] = {8, 8, 8}
	BasePetStats[78] = {7.5, 8.5, 8}
	BasePetStats[83] = {8.5, 7.5, 8}
	BasePetStats[84] = {8, 8, 8}
	BasePetStats[85] = {8.5, 7.5, 8}
	BasePetStats[86] = {8.5, 7.5, 8}
	BasePetStats[87] = {8, 8.5, 7.5}
	BasePetStats[89] = {8, 8, 8}
	BasePetStats[90] = {7, 8.5, 8.5}
	BasePetStats[92] = {8, 8, 8}
	BasePetStats[93] = {6.5, 9, 8.5}
	BasePetStats[94] = {7, 7, 10}
	BasePetStats[95] = {8, 8, 8}
	BasePetStats[106] = {8.5, 7.5, 8}
	BasePetStats[107] = {8, 8, 8}
	BasePetStats[111] = {8, 8, 8}
	BasePetStats[114] = {8.5, 8.5, 7}
	BasePetStats[115] = {8, 8, 8}
	BasePetStats[116] = {8, 8, 8}
	BasePetStats[117] = {8, 8, 8}
	BasePetStats[118] = {8, 8, 8}
	BasePetStats[119] = {8, 8, 8}
	BasePetStats[120] = {8, 8, 8}
	BasePetStats[121] = {8, 8, 8}
	BasePetStats[122] = {8, 8, 8}
	BasePetStats[124] = {8, 8, 8}
	BasePetStats[125] = {8, 8, 8}
	BasePetStats[126] = {8, 8, 8}
	BasePetStats[127] = {8, 7.5, 8.5}
	BasePetStats[128] = {8, 8, 8}
	BasePetStats[130] = {8, 8, 8}
	BasePetStats[131] = {8, 7.5, 8.5}
	BasePetStats[132] = {9, 8, 7}
	BasePetStats[136] = {8, 8, 8}
	BasePetStats[137] = {8, 7, 9}
	BasePetStats[138] = {8.5, 7.5, 8}
	BasePetStats[139] = {7.5, 8.5, 8}
	BasePetStats[140] = {8, 8.5, 7.5}
	BasePetStats[141] = {7.5, 7.5, 9}
	BasePetStats[142] = {8, 8.5, 7.5}
	BasePetStats[143] = {7.5, 8.5, 8}
	BasePetStats[144] = {7.5, 7.5, 9}
	BasePetStats[145] = {8.5, 7.5, 8}
	BasePetStats[146] = {7.5, 8, 8.5}
	BasePetStats[149] = {7.5, 7, 9.5}
	BasePetStats[153] = {8, 8, 8}
	BasePetStats[155] = {8, 8, 8}
	BasePetStats[156] = {8, 8, 8}
	BasePetStats[157] = {8, 8, 8}
	BasePetStats[158] = {8, 8, 8}
	BasePetStats[159] = {8, 8, 8}
	BasePetStats[160] = {8, 8, 8}
	BasePetStats[162] = {8, 8.5, 7.5}
	BasePetStats[163] = {8, 8.5, 7.5}
	BasePetStats[164] = {8, 8.5, 7.5}
	BasePetStats[165] = {8.5, 7.5, 8}
	BasePetStats[166] = {8.5, 8.5, 7}
	BasePetStats[167] = {9, 7.5, 7.5}
	BasePetStats[168] = {8.5, 7.5, 8}
	BasePetStats[169] = {8, 8, 8}
	BasePetStats[170] = {8, 8, 8}
	BasePetStats[171] = {8, 8, 8}
	BasePetStats[172] = {7.5, 8.5, 8}
	BasePetStats[173] = {8, 8.5, 7.5}
	BasePetStats[174] = {8, 8.5, 7.5}
	BasePetStats[175] = {7.5, 8.5, 8}
	BasePetStats[179] = {8.5, 8, 7.5}
	BasePetStats[180] = {8.5, 8, 7.5}
	BasePetStats[183] = {8, 8, 8}
	BasePetStats[186] = {7.5, 8.5, 8}
	BasePetStats[187] = {8.5, 8.5, 7}
	BasePetStats[188] = {8.5, 8.5, 7}
	BasePetStats[189] = {8, 8, 8}
	BasePetStats[190] = {8.5, 8.5, 7}
	BasePetStats[191] = {8.5, 7.5, 8}
	BasePetStats[192] = {8, 8, 8}
	BasePetStats[193] = {8, 8.5, 7.5}
	BasePetStats[194] = {8, 8, 8}
	BasePetStats[195] = {7.5, 7.5, 9}
	BasePetStats[196] = {8.5, 8, 7.5}
	BasePetStats[197] = {7.5, 8, 8.5}
	BasePetStats[198] = {8, 8, 8}
	BasePetStats[199] = {8, 8, 8}
	BasePetStats[200] = {8, 7, 9}
	BasePetStats[201] = {8, 8, 8}
	BasePetStats[202] = {8, 8, 8}
	BasePetStats[203] = {8, 7, 9}
	BasePetStats[204] = {8, 8, 8}
	BasePetStats[205] = {8, 8, 8}
	BasePetStats[206] = {8.5, 8.5, 7}
	BasePetStats[207] = {8, 8, 8}
	BasePetStats[209] = {8, 8, 8}
	BasePetStats[210] = {8, 8, 8}
	BasePetStats[211] = {8.5, 8, 7.5}
	BasePetStats[212] = {8, 8, 8}
	BasePetStats[213] = {8, 8, 8}
	BasePetStats[214] = {8, 8, 8}
	BasePetStats[215] = {8.5, 7.5, 8}
	BasePetStats[216] = {8, 8, 8}
	BasePetStats[217] = {8, 8, 8}
	BasePetStats[218] = {8.5, 7.5, 8}
	BasePetStats[220] = {8, 8, 8}
	BasePetStats[224] = {7, 8.5, 8.5}
	BasePetStats[225] = {8, 8, 8}
	BasePetStats[226] = {8, 8, 8}
	BasePetStats[227] = {8, 8, 8}
	BasePetStats[228] = {8, 8, 8}
	BasePetStats[229] = {8, 8, 8}
	BasePetStats[231] = {8.5, 8, 7.5}
	BasePetStats[232] = {7, 8.5, 8.5}
	BasePetStats[233] = {7, 8.5, 8.5}
	BasePetStats[234] = {7, 8.5, 8.5}
	BasePetStats[235] = {7, 8.5, 8.5}
	BasePetStats[236] = {7.5, 8.5, 8}
	BasePetStats[237] = {7, 8.5, 8.5}
	BasePetStats[238] = {7, 8.5, 8.5}
	BasePetStats[239] = {8, 8, 8}
	BasePetStats[240] = {8.5, 8.5, 7}
	BasePetStats[241] = {8, 8, 8}
	BasePetStats[242] = {7.5, 8.5, 8}
	BasePetStats[243] = {9, 9, 6}
	BasePetStats[244] = {8.5, 9, 6.5}
	BasePetStats[245] = {8, 8, 8}
	BasePetStats[246] = {8, 8, 8}
	BasePetStats[247] = {8, 8, 8}
	BasePetStats[248] = {8, 8, 8}
	BasePetStats[249] = {8.5, 8.5, 7}
	BasePetStats[250] = {7.5, 9, 7.5}
	BasePetStats[251] = {8.5, 8.5, 7}
	BasePetStats[253] = {8, 8, 8}
	BasePetStats[254] = {8, 8, 8}
	BasePetStats[255] = {7.5, 9, 7.5}
	BasePetStats[256] = {8, 9, 7}
	BasePetStats[257] = {8, 8, 8}
	BasePetStats[258] = {8.5, 9, 6.5}
	BasePetStats[259] = {8.5, 7.5, 8}
	BasePetStats[260] = {8, 8.5, 7.5}
	BasePetStats[261] = {8.5, 7.5, 8}
	BasePetStats[262] = {8.5, 7.5, 8}
	BasePetStats[264] = {8.5, 8.5, 7}
	BasePetStats[265] = {9.5, 8, 6.5}
	BasePetStats[266] = {8.5, 8.5, 7}
	BasePetStats[267] = {8, 8, 8}
	BasePetStats[268] = {8.5, 9, 6.5}
	BasePetStats[270] = {8.5, 8.5, 7}
	BasePetStats[271] = {8, 7.5, 8.5}
	BasePetStats[272] = {9, 7.5, 7.5}
	BasePetStats[277] = {8.5, 7.5, 8}
	BasePetStats[278] = {8, 8, 8}
	BasePetStats[279] = {8, 8, 8}
	BasePetStats[280] = {8, 8, 8}
	BasePetStats[281] = {8, 8, 8}
	BasePetStats[282] = {8, 8, 8}
	BasePetStats[283] = {8, 8, 8}
	BasePetStats[285] = {8, 9, 7}
	BasePetStats[286] = {9, 8, 7}
	BasePetStats[287] = {8, 7.5, 8.5}
	BasePetStats[289] = {9.5, 8.5, 6}
	BasePetStats[291] = {9, 7.5, 7.5}
	BasePetStats[292] = {8, 8, 8}
	BasePetStats[293] = {8, 8, 8}
	BasePetStats[294] = {8, 8, 8}
	BasePetStats[296] = {8, 8, 8}
	BasePetStats[297] = {8, 9.5, 6.5}
	BasePetStats[298] = {8, 8, 8}
	BasePetStats[301] = {7, 8.5, 8.5}
	BasePetStats[302] = {8.5, 8.5, 7}
	BasePetStats[303] = {7, 8.5, 8.5}
	BasePetStats[306] = {7, 8.5, 8.5}
	BasePetStats[307] = {8, 8, 8}
	BasePetStats[308] = {8, 8, 8}
	BasePetStats[309] = {6.5, 9, 8.5}
	BasePetStats[310] = {8, 8, 8}
	BasePetStats[311] = {8.5, 8, 7.5}
	BasePetStats[316] = {8.5, 7.5, 8}
	BasePetStats[317] = {8.5, 8.5, 7}
	BasePetStats[318] = {7.5, 8.5, 8}
	BasePetStats[319] = {6.5, 9, 8.5}
	BasePetStats[320] = {8.5, 7.5, 8}
	BasePetStats[321] = {8, 8, 8}
	BasePetStats[323] = {8, 8, 8}
	BasePetStats[325] = {7.5, 9, 7.5}
	BasePetStats[328] = {8, 8, 8}
	BasePetStats[329] = {8, 8, 8}
	BasePetStats[330] = {8, 8, 8}
	BasePetStats[331] = {8, 8, 8}
	BasePetStats[332] = {8, 8, 8}
	BasePetStats[333] = {8, 8, 8}
	BasePetStats[335] = {9, 7.5, 7.5}
	BasePetStats[336] = {8, 8, 8}
	BasePetStats[337] = {8, 8, 8}
	BasePetStats[338] = {8.5, 7.5, 8}
	BasePetStats[339] = {8, 8, 8}
	BasePetStats[340] = {8, 8, 8}
	BasePetStats[341] = {8, 8, 8}
	BasePetStats[342] = {8, 8, 8}
	BasePetStats[343] = {7, 8.5, 8.5}
	BasePetStats[344] = {8.5, 8, 7.5}
	BasePetStats[345] = {8, 8.5, 7.5}
	BasePetStats[346] = {8, 8, 8}
	BasePetStats[347] = {8, 8.75, 7.25}
	BasePetStats[348] = {8.5, 8.5, 7}
	BasePetStats[354] = {8, 8, 8}
	BasePetStats[374] = {8, 8, 8}
	BasePetStats[375] = {8, 8, 8}
	BasePetStats[378] = {8, 7, 9}
	BasePetStats[379] = {8, 7.5, 8.5}
	BasePetStats[380] = {8, 8, 8}
	BasePetStats[381] = {8, 8, 8}
	BasePetStats[382] = {8, 8, 8}
	BasePetStats[383] = {8, 7.5, 8.5}
	BasePetStats[384] = {8, 8, 8}
	BasePetStats[385] = {8, 7.5, 8.5}
	BasePetStats[386] = {8, 7.5, 8.5}
	BasePetStats[387] = {7.5, 8, 8.5}
	BasePetStats[388] = {8.5, 8, 7.5}
	BasePetStats[389] = {8.5, 7.5, 8}
	BasePetStats[390] = {8, 7.5, 8.5}
	BasePetStats[391] = {8, 7, 9}
	BasePetStats[392] = {8, 7.5, 8.5}
	BasePetStats[393] = {8.5, 7, 8.5}
	BasePetStats[394] = {8, 8, 8}
	BasePetStats[395] = {8.5, 8, 7.5}
	BasePetStats[396] = {7, 8.5, 8.5}
	BasePetStats[397] = {8, 8, 8}
	BasePetStats[398] = {8, 7.5, 8.5}
	BasePetStats[399] = {7.5, 8, 8.5}
	BasePetStats[400] = {7, 8.5, 8.5}
	BasePetStats[401] = {8.5, 8, 7.5}
	BasePetStats[402] = {8.5, 8, 7.5}
	BasePetStats[403] = {7.5, 8, 8.5}
	BasePetStats[404] = {8, 7.5, 8.5}
	BasePetStats[405] = {7.5, 8, 8.5}
	BasePetStats[406] = {8.5, 7.5, 8}
	BasePetStats[407] = {7, 8.5, 8.5}
	BasePetStats[408] = {7.5, 8, 8.5}
	BasePetStats[409] = {7, 8, 9}
	BasePetStats[410] = {8, 7.5, 8.5}
	BasePetStats[411] = {8, 8, 8}
	BasePetStats[412] = {7, 8.5, 8.5}
	BasePetStats[414] = {8, 8, 8}
	BasePetStats[415] = {7.5, 8.5, 8}
	BasePetStats[416] = {8, 8, 8}
	BasePetStats[417] = {8, 7.5, 8.5}
	BasePetStats[418] = {7.5, 8, 8.5}
	BasePetStats[419] = {8.5, 7.5, 8}
	BasePetStats[420] = {8.5, 7.5, 8}
	BasePetStats[421] = {8, 8.5, 7.5}
	BasePetStats[422] = {7.5, 8.5, 8}
	BasePetStats[423] = {8.5, 8.5, 7}
	BasePetStats[424] = {8.5, 7, 8.5}
	BasePetStats[425] = {7.5, 8, 8.5}
	BasePetStats[427] = {7, 8.5, 8.5}
	BasePetStats[428] = {7, 8.5, 8.5}
	BasePetStats[429] = {7.5, 8.5, 8}
	BasePetStats[430] = {8, 8.5, 7.5}
	BasePetStats[431] = {7.5, 8, 8.5}
	BasePetStats[432] = {8, 8, 8}
	BasePetStats[433] = {7.5, 8, 8.5}
	BasePetStats[434] = {8, 8, 8}
	BasePetStats[437] = {8, 8, 8}
	BasePetStats[438] = {7.5, 8, 8.5}
	BasePetStats[439] = {8.5, 8, 7.5}
	BasePetStats[440] = {8, 8, 8}
	BasePetStats[441] = {8, 7, 9}
	BasePetStats[442] = {9, 6.5, 8.5}
	BasePetStats[443] = {8, 8, 8}
	BasePetStats[444] = {8, 8, 8}
	BasePetStats[445] = {8, 8, 8}
	BasePetStats[446] = {8.5, 8, 7.5}
	BasePetStats[447] = {8, 7.5, 8.5}
	BasePetStats[448] = {8, 7, 9}
	BasePetStats[449] = {8, 8, 8}
	BasePetStats[450] = {9, 8, 7}
	BasePetStats[452] = {8, 8, 8}
	BasePetStats[453] = {9, 8, 7}
	BasePetStats[454] = {8, 7.5, 8.5}
	BasePetStats[455] = {8, 8, 8}
	BasePetStats[456] = {8, 8.5, 7.5}
	BasePetStats[457] = {9, 8, 7}
	BasePetStats[458] = {8.5, 8.5, 7}
	BasePetStats[459] = {7, 8.5, 8.5}
	BasePetStats[460] = {7.5, 8.5, 8}
	BasePetStats[461] = {9, 8, 7}
	BasePetStats[462] = {8, 8, 8}
	BasePetStats[463] = {9, 9, 6}
	BasePetStats[464] = {8, 8, 8}
	BasePetStats[465] = {7, 8.5, 8.5}
	BasePetStats[466] = {7.5, 8, 8.5}
	BasePetStats[467] = {7.5, 8.5, 8}
	BasePetStats[468] = {7.5, 8.5, 8}
	BasePetStats[469] = {7, 8.5, 8.5}
	BasePetStats[470] = {7, 8.5, 8.5}
	BasePetStats[471] = {8.5, 7.5, 8}
	BasePetStats[472] = {8.5, 7.5, 8}
	BasePetStats[473] = {9, 7.5, 7.5}
	BasePetStats[474] = {6, 8, 10}
	BasePetStats[475] = {8.5, 7, 8.5}
	BasePetStats[476] = {7.5, 7.5, 9}
	BasePetStats[477] = {7.5, 7.5, 9}
	BasePetStats[478] = {8.5, 8, 7.5}
	BasePetStats[479] = {8, 6.5, 9.5}
	BasePetStats[480] = {8, 8.5, 7.5}
	BasePetStats[482] = {7.5, 8, 8.5}
	BasePetStats[483] = {8.5, 7.5, 8}
	BasePetStats[484] = {7, 8.5, 8.5}
	BasePetStats[485] = {9, 7.5, 7.5}
	BasePetStats[486] = {8, 7.5, 8.5}
	BasePetStats[487] = {8, 8, 8}
	BasePetStats[488] = {7.5, 8, 8.5}
	BasePetStats[489] = {8, 8.5, 7.5}
	BasePetStats[491] = {7, 9, 8}
	BasePetStats[492] = {8, 8.5, 7.5}
	BasePetStats[493] = {9.5, 8.5, 6}
	BasePetStats[494] = {8, 8, 8}
	BasePetStats[495] = {8.5, 7.5, 8}
	BasePetStats[496] = {9.5, 8.5, 6}
	BasePetStats[497] = {8.5, 7, 8.5}
	BasePetStats[498] = {8.5, 8, 7.5}
	BasePetStats[499] = {8, 7.5, 8.5}
	BasePetStats[500] = {8, 8, 8}
	BasePetStats[502] = {8.5, 7.5, 8}
	BasePetStats[503] = {7.5, 7.5, 9}
	BasePetStats[504] = {8, 8.5, 7.5}
	BasePetStats[505] = {7.5, 8, 8.5}
	BasePetStats[506] = {7, 8.5, 8.5}
	BasePetStats[507] = {7.5, 8.5, 8}
	BasePetStats[508] = {8, 8, 8}
	BasePetStats[509] = {8, 8, 8}
	BasePetStats[510] = {8.5, 7.5, 8}
	BasePetStats[511] = {7.5, 8, 8.5}
	BasePetStats[512] = {7.5, 8.5, 8}
	BasePetStats[513] = {8, 8, 8}
	BasePetStats[514] = {8, 8, 8}
	BasePetStats[515] = {8, 8, 8}
	BasePetStats[517] = {8, 8, 8}
	BasePetStats[518] = {9, 8.5, 6.5}
	BasePetStats[519] = {8.5, 8, 7.5}
	BasePetStats[521] = {7, 9, 8}
	BasePetStats[523] = {9, 8, 7}
	BasePetStats[525] = {8, 8, 8}
	BasePetStats[528] = {7.5, 8, 8.5}
	BasePetStats[529] = {8, 8, 8}
	BasePetStats[530] = {8, 8, 8}
	BasePetStats[532] = {8.5, 9, 6.5}
	BasePetStats[534] = {7.5, 8.5, 8}
	BasePetStats[535] = {8, 8, 8}
	BasePetStats[536] = {8.5, 8, 7.5}
	BasePetStats[537] = {8.5, 8, 7.5}
	BasePetStats[538] = {8.5, 8.5, 7}
	BasePetStats[539] = {8, 7.5, 8.5}
	BasePetStats[540] = {8, 7.5, 8.5}
	BasePetStats[541] = {8.5, 7, 8.5}
	BasePetStats[542] = {8.5, 7.5, 8}
	BasePetStats[543] = {7.5, 8.5, 8}
	BasePetStats[544] = {8.5, 8.5, 7}
	BasePetStats[545] = {8, 8, 8}
	BasePetStats[546] = {7.5, 8.5, 8}
	BasePetStats[547] = {8, 7, 9}
	BasePetStats[548] = {7.5, 8.5, 8}
	BasePetStats[549] = {8, 8, 8}
	BasePetStats[550] = {8, 7.5, 8.5}
	BasePetStats[552] = {7.5, 8.5, 8}
	BasePetStats[553] = {8, 7.5, 8.5}
	BasePetStats[554] = {7.5, 8.5, 8}
	BasePetStats[555] = {8.5, 7, 8.5}
	BasePetStats[556] = {7.5, 8.5, 8}
	BasePetStats[557] = {7.5, 8.5, 8}
	BasePetStats[558] = {8, 8, 8}
	BasePetStats[559] = {7.5, 9, 7.5}
	BasePetStats[560] = {8.5, 7.5, 8}
	BasePetStats[562] = {7.5, 8, 8.5}
	BasePetStats[564] = {9.5, 7.5, 7}
	BasePetStats[565] = {8.5, 7.5, 8}
	BasePetStats[566] = {7.5, 7.5, 9}
	BasePetStats[567] = {7.5, 8, 8.5}
	BasePetStats[568] = {9.5, 8.5, 6}
	BasePetStats[569] = {8.5, 7.5, 8}
	BasePetStats[570] = {8, 8, 8}
	BasePetStats[571] = {7.5, 8, 8.5}
	BasePetStats[572] = {8.5, 8, 7.5}
	BasePetStats[573] = {9, 7, 8}
	BasePetStats[626] = {7.5, 8, 8.5}
	BasePetStats[627] = {8.5, 8.5, 7}
	BasePetStats[628] = {8.5, 8, 7.5}
	BasePetStats[629] = {8.5, 8, 7.5}
	BasePetStats[630] = {8, 8, 8}
	BasePetStats[631] = {7.5, 8, 8.5}
	BasePetStats[632] = {7.5, 8, 8.5}
	BasePetStats[633] = {8, 8, 8}
	BasePetStats[634] = {7, 8.5, 8.5}
	BasePetStats[635] = {7.5, 8, 8.5}
	BasePetStats[637] = {8, 8, 8}
	BasePetStats[638] = {8.5, 7, 8.5}
	BasePetStats[639] = {8, 7.5, 8.5}
	BasePetStats[640] = {8, 7, 9}
	BasePetStats[641] = {8, 7, 9}
	BasePetStats[644] = {8, 7.5, 8.5}
	BasePetStats[645] = {8, 8, 8}
	BasePetStats[646] = {8, 8, 8}
	BasePetStats[647] = {8, 8, 8}
	BasePetStats[648] = {9, 7.5, 7.5}
	BasePetStats[649] = {9, 7.5, 7.5}
	BasePetStats[650] = {8.5, 8, 7.5}
	BasePetStats[652] = {8, 8, 8}
	BasePetStats[665] = {7.5, 8.5, 8}
	BasePetStats[666] = {8, 8, 8}
	BasePetStats[671] = {8, 8, 8}
	BasePetStats[675] = {8, 7.5, 8.5}
	BasePetStats[677] = {8, 8, 8}
	BasePetStats[678] = {8, 8, 8}
	BasePetStats[679] = {8, 8, 8}
	BasePetStats[680] = {8, 8, 8}
	BasePetStats[699] = {7, 8.5, 8.5}
	BasePetStats[702] = {8.5, 7.5, 8}
	BasePetStats[703] = {8, 8, 8}
	BasePetStats[705] = {8, 8.5, 7.5}
	BasePetStats[706] = {8, 8, 8}
	BasePetStats[707] = {8, 8, 8}
	BasePetStats[708] = {8, 7.5, 8.5}
	BasePetStats[709] = {8, 7.5, 8.5}
	BasePetStats[710] = {8, 8, 8}
	BasePetStats[711] = {8, 8, 8}
	BasePetStats[712] = {8, 8, 8}
	BasePetStats[713] = {9, 7.5, 7.5}
	BasePetStats[714] = {7, 8.5, 8.5}
	BasePetStats[715] = {8, 8, 8}
	BasePetStats[716] = {7, 8.5, 8.5}
	BasePetStats[717] = {7.5, 8.5, 8}
	BasePetStats[718] = {8, 8, 8}
	BasePetStats[722] = {7.5, 8.5, 8}
	BasePetStats[723] = {9, 7.5, 7.5}
	BasePetStats[724] = {8, 8, 8}
	BasePetStats[725] = {8, 8, 8}
	BasePetStats[726] = {7, 8.5, 8.5}
	BasePetStats[727] = {8, 8, 8}
	BasePetStats[728] = {8, 8, 8}
	BasePetStats[729] = {8, 7, 9}
	BasePetStats[730] = {8, 7, 9}
	BasePetStats[731] = {7, 8.5, 8.5}
	BasePetStats[732] = {8, 8.5, 7.5}
	BasePetStats[733] = {8, 8, 8}
	BasePetStats[737] = {6.5, 8, 9.5}
	BasePetStats[739] = {7, 8, 9}
	BasePetStats[740] = {8, 7.5, 8.5}
	BasePetStats[741] = {8, 8, 8}
	BasePetStats[742] = {8, 8, 8}
	BasePetStats[743] = {9.5, 8.5, 6}
	BasePetStats[744] = {8.5, 7, 8.5}
	BasePetStats[745] = {8, 8, 8}
	BasePetStats[746] = {8.5, 9, 6.5}
	BasePetStats[747] = {7.5, 8.5, 8}
	BasePetStats[748] = {8, 8.5, 7.5}
	BasePetStats[749] = {8, 8, 8}
	BasePetStats[750] = {8, 8, 8}
	BasePetStats[751] = {8, 7.5, 8.5}
	BasePetStats[752] = {9, 7.5, 7.5}
	BasePetStats[753] = {7.5, 8.5, 8}
	BasePetStats[754] = {8, 8, 8}
	BasePetStats[755] = {9, 6.5, 8.5}
	BasePetStats[756] = {8.5, 7, 8.5}
	BasePetStats[757] = {8.5, 8, 7.5}
	BasePetStats[758] = {7.5, 8.5, 8}
	BasePetStats[792] = {8, 8.5, 7.5}
	BasePetStats[800] = {8, 8, 8}
	BasePetStats[802] = {8.5, 8.5, 7}
	BasePetStats[817] = {8.5, 8, 7.5}
	BasePetStats[818] = {8, 8.5, 7.5}
	BasePetStats[819] = {7.5, 8.5, 8}
	BasePetStats[820] = {8, 8, 8}
	BasePetStats[821] = {8, 8, 8}
	BasePetStats[823] = {8, 8, 8}
	BasePetStats[824] = {8, 8, 8}
	BasePetStats[825] = {8, 8, 8}
	BasePetStats[826] = {8, 8, 8}
	BasePetStats[827] = {8, 8, 8}
	BasePetStats[828] = {8, 8, 8}
	BasePetStats[829] = {8, 8, 8}
	BasePetStats[830] = {8, 8, 8}
	BasePetStats[831] = {8, 8, 8}
	BasePetStats[832] = {8, 8, 8}
	BasePetStats[833] = {8, 8, 8}
	BasePetStats[834] = {8.5, 8, 7.5}
	BasePetStats[835] = {8, 8, 8}
	BasePetStats[836] = {7.5, 7, 9.5}
	BasePetStats[837] = {8.5, 8, 7.5}
	BasePetStats[838] = {8, 8, 8}
	BasePetStats[844] = {8, 8.5, 7.5}
	BasePetStats[845] = {8, 8, 8}
	BasePetStats[846] = {6, 8, 10}
	BasePetStats[847] = {8, 8, 8}
	BasePetStats[848] = {8, 7, 9}
	BasePetStats[849] = {8, 8, 8}
	BasePetStats[850] = {8, 8, 8}
	BasePetStats[851] = {7.5, 8, 8.5}
	BasePetStats[855] = {7.5, 8.5, 8}
	BasePetStats[856] = {8, 8, 8}
	BasePetStats[868] = {8, 8, 8}
	BasePetStats[872] = {8, 8, 8}
	BasePetStats[873] = {8, 8, 8}
	BasePetStats[874] = {8, 8, 8}
	BasePetStats[875] = {8, 8, 8}
	BasePetStats[876] = {8, 8, 8}
	BasePetStats[877] = {8, 8, 8}
	BasePetStats[878] = {8, 8, 8}
	BasePetStats[879] = {8, 8, 8}
	BasePetStats[880] = {8, 8, 8}
	BasePetStats[881] = {8, 8, 8}
	BasePetStats[882] = {8, 8, 8}
	BasePetStats[883] = {8, 8, 8}
	BasePetStats[884] = {8, 8, 8}
	BasePetStats[885] = {8, 8, 8}
	BasePetStats[886] = {8, 8, 8}
	BasePetStats[887] = {8, 8, 8}
	BasePetStats[888] = {8, 8, 8}
	BasePetStats[889] = {8, 8, 8}
	BasePetStats[890] = {8, 8, 8}
	BasePetStats[891] = {8, 8, 8}
	BasePetStats[892] = {8, 8, 8}
	BasePetStats[893] = {8, 8, 8}
	BasePetStats[894] = {8, 8, 8}
	BasePetStats[895] = {8, 8, 8}
	BasePetStats[896] = {8, 8, 8}
	BasePetStats[897] = {8, 8, 8}
	BasePetStats[898] = {8, 8, 8}
	BasePetStats[899] = {8, 8, 8}
	BasePetStats[900] = {8, 8, 8}
	BasePetStats[901] = {8, 8, 8}
	BasePetStats[902] = {8, 8, 8}
	BasePetStats[903] = {7.5, 9, 7.5}
	BasePetStats[904] = {8, 8, 8}
	BasePetStats[905] = {8, 8, 8}
	BasePetStats[906] = {8, 8, 8}
	BasePetStats[907] = {8, 8, 8}
	BasePetStats[908] = {8, 8, 8}
	BasePetStats[909] = {8, 8, 8}
	BasePetStats[911] = {8, 8.5, 7.5}
	BasePetStats[912] = {8, 8.5, 7.5}
	BasePetStats[913] = {8, 8.5, 7.5}
	BasePetStats[915] = {8, 8, 8}
	BasePetStats[916] = {8, 8, 8}
	BasePetStats[917] = {8, 8, 8}
	BasePetStats[921] = {8, 8, 8}
	BasePetStats[922] = {8, 8, 8}
	BasePetStats[923] = {8.5, 7.5, 8}
	BasePetStats[924] = {8, 8, 8}
	BasePetStats[925] = {8, 8, 8}
	BasePetStats[926] = {8, 8, 8}
	BasePetStats[927] = {8, 8, 8}
	BasePetStats[928] = {8, 8, 8}
	BasePetStats[929] = {8, 8, 8}
	BasePetStats[931] = {8, 8, 8}
	BasePetStats[932] = {8, 8, 8}
	BasePetStats[933] = {8, 8, 8}
	BasePetStats[934] = {8, 8, 8}
	BasePetStats[935] = {8, 8, 8}
	BasePetStats[936] = {8, 8, 8}
	BasePetStats[937] = {8, 8, 8}
	BasePetStats[938] = {8, 8, 8}
	BasePetStats[939] = {8, 8, 8}
	BasePetStats[941] = {8, 8, 8}
	BasePetStats[942] = {8, 8, 8}
	BasePetStats[943] = {8, 8, 8}
	BasePetStats[944] = {8, 8, 8}
	BasePetStats[945] = {8, 8, 8}
	BasePetStats[946] = {8, 8, 8}
	BasePetStats[947] = {8, 8, 8}
	BasePetStats[948] = {8, 8, 8}
	BasePetStats[949] = {8, 8, 8}
	BasePetStats[950] = {8, 8, 8}
	BasePetStats[951] = {8, 8, 8}
	BasePetStats[952] = {8, 8, 8}
	BasePetStats[953] = {8, 8, 8}
	BasePetStats[954] = {8, 8, 8}
	BasePetStats[955] = {8, 8, 8}
	BasePetStats[956] = {8, 8, 8}
	BasePetStats[957] = {8, 8, 8}
	BasePetStats[958] = {8, 8, 8}
	BasePetStats[959] = {8, 8, 8}
	BasePetStats[960] = {8, 8, 8}
	BasePetStats[961] = {8, 8, 8}
	BasePetStats[962] = {8, 8, 8}
	BasePetStats[963] = {8, 8, 8}
	BasePetStats[964] = {8, 8, 8}
	BasePetStats[965] = {8, 8, 8}
	BasePetStats[966] = {8, 8, 8}
	BasePetStats[967] = {8, 8, 8}
	BasePetStats[968] = {8, 8, 8}
	BasePetStats[969] = {8, 8, 8}
	BasePetStats[970] = {8, 8, 8}
	BasePetStats[971] = {8, 8, 8}
	BasePetStats[972] = {8, 8, 8}
	BasePetStats[973] = {8, 8, 8}
	BasePetStats[974] = {8, 8, 8}
	BasePetStats[975] = {8, 8, 8}
	BasePetStats[976] = {8, 8, 8}
	BasePetStats[977] = {8.5, 8.5, 8.5}
	BasePetStats[978] = {8.5, 8.5, 8.5}
	BasePetStats[979] = {8.5, 8.5, 8.5}
	BasePetStats[980] = {8.5, 8.5, 8.5}
	BasePetStats[981] = {8.5, 8.5, 8.5}
	BasePetStats[982] = {8.5, 8.5, 8.5}
	BasePetStats[983] = {8.5, 8.5, 8.5}
	BasePetStats[984] = {8.5, 8.5, 8.5}
	BasePetStats[985] = {8.5, 8.5, 8.5}
	BasePetStats[986] = {8.5, 8.5, 8.5}
	BasePetStats[987] = {8.5, 8.5, 8.5}
	BasePetStats[988] = {8.5, 8.5, 8.5}
	BasePetStats[989] = {8, 8, 8}
	BasePetStats[990] = {8, 8, 8}
	BasePetStats[991] = {8, 8, 8}
	BasePetStats[992] = {8, 8, 8}
	BasePetStats[993] = {8, 8, 8}
	BasePetStats[994] = {8, 8, 8}
	BasePetStats[995] = {8, 8, 8}
	BasePetStats[996] = {8, 8, 8}
	BasePetStats[997] = {8, 8, 8}
	BasePetStats[998] = {8, 8, 8}
	BasePetStats[999] = {8, 8, 8}
	BasePetStats[1000] = {8, 8, 8}
	BasePetStats[1001] = {8, 8, 8}
	BasePetStats[1002] = {9, 9, 9}
	BasePetStats[1003] = {9, 9, 9}
	BasePetStats[1004] = {8, 8, 8}
	BasePetStats[1005] = {8, 8, 8}
	BasePetStats[1006] = {8, 8, 8}
	BasePetStats[1007] = {8, 8, 8}
	BasePetStats[1008] = {8, 8, 8}
	BasePetStats[1009] = {8, 8, 8}
	BasePetStats[1010] = {8, 8, 8}
	BasePetStats[1011] = {8, 8, 8}
	BasePetStats[1012] = {8, 8, 8}
	BasePetStats[1013] = {9, 7.5, 7.5}
	BasePetStats[1039] = {7.5, 7.5, 9}
	BasePetStats[1040] = {8, 8, 8}
	BasePetStats[1042] = {6.75, 10.5, 6.75}
	BasePetStats[1061] = {8, 8, 8}
	BasePetStats[1062] = {8, 7.5, 8.5}
	BasePetStats[1063] = {8.5, 8.5, 7}
	BasePetStats[1065] = {8.5, 8.5, 7}
	BasePetStats[1066] = {8, 8, 8}
	BasePetStats[1067] = {8.5, 7.5, 8}
	BasePetStats[1068] = {8, 8, 8}
	BasePetStats[1073] = {8, 8, 8}
	BasePetStats[1117] = {7.5, 8.5, 8.5}
	BasePetStats[1124] = {8, 8, 8}
	BasePetStats[1125] = {8, 8, 8}
	BasePetStats[1126] = {8, 8, 8}
	BasePetStats[1127] = {7.5, 8.5, 8}
	BasePetStats[1128] = {8, 8, 8}
	BasePetStats[1129] = {8, 8, 8}
	BasePetStats[1130] = {8, 8, 8}
	BasePetStats[1131] = {8, 8, 8}
	BasePetStats[1132] = {8, 8, 8}
	BasePetStats[1133] = {8, 8, 8}
	BasePetStats[1134] = {8, 8, 8}
	BasePetStats[1135] = {8, 8, 8}
	BasePetStats[1136] = {8, 8, 8}
	BasePetStats[1137] = {8, 8, 8}
	BasePetStats[1138] = {8, 8, 8}
	BasePetStats[1139] = {8, 8, 8}
	BasePetStats[1140] = {8, 8, 8}
	BasePetStats[1141] = {8, 8, 8}
	BasePetStats[1142] = {8.5, 7.5, 8}
	BasePetStats[1143] = {8, 8, 8}
	BasePetStats[1144] = {8, 8, 8}
	BasePetStats[1145] = {8, 8, 8}
	BasePetStats[1146] = {8, 8, 8}
	BasePetStats[1147] = {8, 8, 8}
	BasePetStats[1149] = {8, 8, 8}
	BasePetStats[1150] = {8, 8, 8}
	BasePetStats[1151] = {8, 8, 8}
	BasePetStats[1152] = {7.5, 8.5, 8}
	BasePetStats[1153] = {8, 8, 8}
	BasePetStats[1154] = {8, 8, 8}
	BasePetStats[1155] = {8, 8.5, 7.5}
	BasePetStats[1156] = {8, 8, 8}
	BasePetStats[1157] = {8, 8, 8}
	BasePetStats[1158] = {8, 8, 8}
	BasePetStats[1159] = {7.5, 8.5, 8}
	BasePetStats[1160] = {8.5, 8, 7.5}
	BasePetStats[1161] = {8, 8.5, 7.5}
	BasePetStats[1162] = {7, 9, 8}
	BasePetStats[1163] = {9, 8, 7}
	BasePetStats[1164] = {7.5, 8, 8.5}
	BasePetStats[1165] = {8, 8.5, 7.5}
	BasePetStats[1166] = {8, 8.5, 7.5}
	BasePetStats[1167] = {8, 8.5, 7.5}
	BasePetStats[1168] = {8, 8, 8}
	
	BreedsPerSpecies[39] = {11}
	BreedsPerSpecies[40] = {8}
	BreedsPerSpecies[41] = {4}
	BreedsPerSpecies[42] = {7}
	BreedsPerSpecies[43] = {3}
	BreedsPerSpecies[44] = {5}
	BreedsPerSpecies[45] = {3}
	BreedsPerSpecies[46] = {12}
	BreedsPerSpecies[47] = {3, 5}
	BreedsPerSpecies[49] = {3}
	BreedsPerSpecies[50] = {11}
	BreedsPerSpecies[51] = {3, 5}
	BreedsPerSpecies[52] = {3, 10, 11, 12}
	BreedsPerSpecies[55] = {3, 5, 6, 9}
	BreedsPerSpecies[56] = {8}
	BreedsPerSpecies[57] = {4}
	BreedsPerSpecies[58] = {8}
	BreedsPerSpecies[59] = {9}
	BreedsPerSpecies[64] = {9}
	BreedsPerSpecies[65] = {12}
	BreedsPerSpecies[67] = {3, 8, 10}
	BreedsPerSpecies[68] = {3, 6, 7}
	BreedsPerSpecies[69] = {3, 10, 11}
	BreedsPerSpecies[70] = {3, 5, 12}
	BreedsPerSpecies[72] = {3, 5, 11}
	BreedsPerSpecies[74] = {11}
	BreedsPerSpecies[75] = {5}
	BreedsPerSpecies[77] = {3}
	BreedsPerSpecies[78] = {12}
	BreedsPerSpecies[83] = {8}
	BreedsPerSpecies[84] = {3, 10, 11, 12}
	BreedsPerSpecies[85] = {9}
	BreedsPerSpecies[86] = {7}
	BreedsPerSpecies[87] = {5}
	BreedsPerSpecies[89] = {6}
	BreedsPerSpecies[90] = {7}
	BreedsPerSpecies[92] = {3}
	BreedsPerSpecies[93] = {4}
	BreedsPerSpecies[94] = {5}
	BreedsPerSpecies[95] = {3}
	BreedsPerSpecies[106] = {10}
	BreedsPerSpecies[107] = {3}
	BreedsPerSpecies[111] = {12}
	BreedsPerSpecies[114] = {12}
	BreedsPerSpecies[116] = {12}
	BreedsPerSpecies[117] = {3}
	BreedsPerSpecies[118] = {3}
	BreedsPerSpecies[119] = {3}
	BreedsPerSpecies[120] = {3}
	BreedsPerSpecies[121] = {3}
	BreedsPerSpecies[122] = {5}
	BreedsPerSpecies[124] = {3}
	BreedsPerSpecies[125] = {5}
	BreedsPerSpecies[126] = {10}
	BreedsPerSpecies[127] = {7}
	BreedsPerSpecies[128] = {3}
	BreedsPerSpecies[130] = {3}
	BreedsPerSpecies[131] = {8}
	BreedsPerSpecies[132] = {6}
	BreedsPerSpecies[136] = {3, 7, 10, 12}
	BreedsPerSpecies[137] = {3, 5, 11}
	BreedsPerSpecies[138] = {3, 12}
	BreedsPerSpecies[139] = {3, 8, 12}
	BreedsPerSpecies[140] = {3, 4, 12}
	BreedsPerSpecies[141] = {3, 6, 12}
	BreedsPerSpecies[142] = {3, 5}
	BreedsPerSpecies[143] = {3, 5, 8}
	BreedsPerSpecies[144] = {3, 5, 11}
	BreedsPerSpecies[145] = {3, 5, 6, 8}
	BreedsPerSpecies[146] = {3, 5, 9, 12}
	BreedsPerSpecies[149] = {9}
	BreedsPerSpecies[153] = {7}
	BreedsPerSpecies[156] = {3}
	BreedsPerSpecies[157] = {3}
	BreedsPerSpecies[158] = {3}
	BreedsPerSpecies[159] = {6}
	BreedsPerSpecies[160] = {4}
	BreedsPerSpecies[162] = {10}
	BreedsPerSpecies[163] = {8}
	BreedsPerSpecies[164] = {3}
	BreedsPerSpecies[165] = {9}
	BreedsPerSpecies[166] = {7}
	BreedsPerSpecies[167] = {3, 6, 9}
	BreedsPerSpecies[168] = {5}
	BreedsPerSpecies[169] = {3}
	BreedsPerSpecies[170] = {7}
	BreedsPerSpecies[171] = {7}
	BreedsPerSpecies[172] = {10}
	BreedsPerSpecies[173] = {7}
	BreedsPerSpecies[174] = {3}
	BreedsPerSpecies[175] = {5}
	BreedsPerSpecies[179] = {7}
	BreedsPerSpecies[180] = {7}
	BreedsPerSpecies[183] = {3}
	BreedsPerSpecies[186] = {3, 4, 5, 8}
	BreedsPerSpecies[187] = {8}
	BreedsPerSpecies[188] = {6}
	BreedsPerSpecies[189] = {3}
	BreedsPerSpecies[190] = {6, 7, 12}
	BreedsPerSpecies[191] = {3}
	BreedsPerSpecies[192] = {9}
	BreedsPerSpecies[193] = {4}
	BreedsPerSpecies[194] = {3, 5, 8, 9, 11}
	BreedsPerSpecies[195] = {5, 8, 9, 11}
	BreedsPerSpecies[196] = {7}
	BreedsPerSpecies[197] = {8}
	BreedsPerSpecies[198] = {11}
	BreedsPerSpecies[199] = {10}
	BreedsPerSpecies[200] = {5}
	BreedsPerSpecies[201] = {7}
	BreedsPerSpecies[202] = {7}
	BreedsPerSpecies[203] = {12}
	BreedsPerSpecies[204] = {3}
	BreedsPerSpecies[205] = {7}
	BreedsPerSpecies[206] = {3, 9, 11}
	BreedsPerSpecies[207] = {8}
	BreedsPerSpecies[209] = {3}
	BreedsPerSpecies[210] = {5}
	BreedsPerSpecies[211] = {6}
	BreedsPerSpecies[212] = {3}
	BreedsPerSpecies[213] = {5}
	BreedsPerSpecies[214] = {3}
	BreedsPerSpecies[215] = {10}
	BreedsPerSpecies[216] = {3}
	BreedsPerSpecies[217] = {7}
	BreedsPerSpecies[218] = {4}
	BreedsPerSpecies[220] = {9}
	BreedsPerSpecies[224] = {10}
	BreedsPerSpecies[225] = {3}
	BreedsPerSpecies[226] = {4}
	BreedsPerSpecies[227] = {4}
	BreedsPerSpecies[228] = {7}
	BreedsPerSpecies[229] = {3}
	BreedsPerSpecies[231] = {3}
	BreedsPerSpecies[232] = {8}
	BreedsPerSpecies[233] = {8}
	BreedsPerSpecies[234] = {10}
	BreedsPerSpecies[235] = {10}
	BreedsPerSpecies[236] = {6}
	BreedsPerSpecies[237] = {3}
	BreedsPerSpecies[238] = {11}
	BreedsPerSpecies[239] = {4}
	BreedsPerSpecies[240] = {3}
	BreedsPerSpecies[241] = {3}
	BreedsPerSpecies[242] = {8}
	BreedsPerSpecies[243] = {10}
	BreedsPerSpecies[244] = {7}
	BreedsPerSpecies[245] = {8}
	BreedsPerSpecies[246] = {3}
	BreedsPerSpecies[247] = {6}
	BreedsPerSpecies[248] = {8}
	BreedsPerSpecies[249] = {7}
	BreedsPerSpecies[250] = {8}
	BreedsPerSpecies[251] = {3}
	BreedsPerSpecies[253] = {3}
	BreedsPerSpecies[254] = {3, 5, 8}
	BreedsPerSpecies[255] = {6}
	BreedsPerSpecies[256] = {7}
	BreedsPerSpecies[258] = {6}
	BreedsPerSpecies[259] = {12}
	BreedsPerSpecies[260] = {8}
	BreedsPerSpecies[261] = {4}
	BreedsPerSpecies[262] = {5}
	BreedsPerSpecies[264] = {8}
	BreedsPerSpecies[265] = {6}
	BreedsPerSpecies[266] = {8}
	BreedsPerSpecies[267] = {3}
	BreedsPerSpecies[268] = {4}
	BreedsPerSpecies[270] = {9}
	BreedsPerSpecies[271] = {3, 9, 10}
	BreedsPerSpecies[272] = {6, 9}
	BreedsPerSpecies[277] = {11}
	BreedsPerSpecies[278] = {9}
	BreedsPerSpecies[279] = {8}
	BreedsPerSpecies[280] = {3}
	BreedsPerSpecies[281] = {3}
	BreedsPerSpecies[282] = {3}
	BreedsPerSpecies[283] = {3}
	BreedsPerSpecies[285] = {10}
	BreedsPerSpecies[286] = {7}
	BreedsPerSpecies[287] = {3}
	BreedsPerSpecies[289] = {6}
	BreedsPerSpecies[291] = {12}
	BreedsPerSpecies[292] = {3}
	BreedsPerSpecies[293] = {9}
	BreedsPerSpecies[294] = {8}
	BreedsPerSpecies[296] = {3}
	BreedsPerSpecies[297] = {4}
	BreedsPerSpecies[298] = {3}
	BreedsPerSpecies[301] = {11}
	BreedsPerSpecies[302] = {7}
	BreedsPerSpecies[303] = {5}
	BreedsPerSpecies[306] = {11}
	BreedsPerSpecies[307] = {3}
	BreedsPerSpecies[308] = {3}
	BreedsPerSpecies[309] = {8}
	BreedsPerSpecies[310] = {8}
	BreedsPerSpecies[311] = {3}
	BreedsPerSpecies[316] = {3}
	BreedsPerSpecies[317] = {3}
	BreedsPerSpecies[318] = {3}
	BreedsPerSpecies[319] = {10}
	BreedsPerSpecies[320] = {7}
	BreedsPerSpecies[321] = {6}
	BreedsPerSpecies[323] = {8}
	BreedsPerSpecies[325] = {5, 8, 10}
	BreedsPerSpecies[328] = {4}
	BreedsPerSpecies[329] = {8}
	BreedsPerSpecies[330] = {10}
	BreedsPerSpecies[331] = {3}
	BreedsPerSpecies[332] = {3}
	BreedsPerSpecies[333] = {11}
	BreedsPerSpecies[335] = {12}
	BreedsPerSpecies[336] = {3}
	BreedsPerSpecies[337] = {12}
	BreedsPerSpecies[338] = {7}
	BreedsPerSpecies[339] = {12}
	BreedsPerSpecies[340] = {3}
	BreedsPerSpecies[341] = {3}
	BreedsPerSpecies[342] = {3}
	BreedsPerSpecies[343] = {3, 8}
	BreedsPerSpecies[346] = {3}
	BreedsPerSpecies[347] = {3}
	BreedsPerSpecies[348] = {8}
	BreedsPerSpecies[374] = {7, 8, 9, 10, 11, 12}
	BreedsPerSpecies[378] = {3, 5, 7, 9, 11, 12}
	BreedsPerSpecies[379] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[380] = {3, 12}
	BreedsPerSpecies[381] = {9}
	BreedsPerSpecies[383] = {8, 11}
	BreedsPerSpecies[385] = {3, 5, 8, 11, 12}
	BreedsPerSpecies[386] = {3, 5, 11}
	BreedsPerSpecies[387] = {3, 5}
	BreedsPerSpecies[388] = {3, 6, 7}
	BreedsPerSpecies[389] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12}
	BreedsPerSpecies[391] = {3, 5, 9}
	BreedsPerSpecies[392] = {3, 5, 9, 11}
	BreedsPerSpecies[393] = {5, 6, 7, 9, 11, 12}
	BreedsPerSpecies[395] = {3, 6, 7}
	BreedsPerSpecies[396] = {8, 11}
	BreedsPerSpecies[397] = {3, 9, 11, 12}
	BreedsPerSpecies[398] = {3, 5, 9, 11}
	BreedsPerSpecies[399] = {3, 5, 8}
	BreedsPerSpecies[400] = {3, 4, 9, 11}
	BreedsPerSpecies[401] = {3, 6, 7}
	BreedsPerSpecies[402] = {3, 9, 12}
	BreedsPerSpecies[403] = {3, 5, 8, 10}
	BreedsPerSpecies[404] = {3, 12}
	BreedsPerSpecies[405] = {3, 4, 7}
	BreedsPerSpecies[406] = {3, 6, 7, 9}
	BreedsPerSpecies[407] = {3, 5, 8, 11}
	BreedsPerSpecies[408] = {3, 5, 11}
	BreedsPerSpecies[409] = {5, 8, 10}
	BreedsPerSpecies[410] = {3, 5, 9, 11}
	BreedsPerSpecies[411] = {3, 4}
	BreedsPerSpecies[412] = {3, 5, 11}
	BreedsPerSpecies[414] = {3, 8}
	BreedsPerSpecies[415] = {6, 7, 9}
	BreedsPerSpecies[416] = {3, 5, 8}
	BreedsPerSpecies[417] = {3, 5, 9, 11}
	BreedsPerSpecies[418] = {3, 11}
	BreedsPerSpecies[419] = {3, 11}
	BreedsPerSpecies[420] = {3, 7, 12}
	BreedsPerSpecies[421] = {3, 9, 12}
	BreedsPerSpecies[422] = {3, 5, 8}
	BreedsPerSpecies[423] = {3, 6, 9}
	BreedsPerSpecies[424] = {5, 6, 7, 9, 11, 12}
	BreedsPerSpecies[425] = {3, 8, 10}
	BreedsPerSpecies[427] = {3, 9}
	BreedsPerSpecies[428] = {3, 5, 8, 11}
	BreedsPerSpecies[429] = {4, 6, 7, 9}
	BreedsPerSpecies[430] = {5}
	BreedsPerSpecies[431] = {8, 9}
	BreedsPerSpecies[432] = {3, 8}
	BreedsPerSpecies[433] = {3, 5, 7}
	BreedsPerSpecies[437] = {3, 10}
	BreedsPerSpecies[438] = {6, 9}
	BreedsPerSpecies[439] = {6, 9}
	BreedsPerSpecies[440] = {3, 4, 8}
	BreedsPerSpecies[441] = {5, 7, 9}
	BreedsPerSpecies[442] = {6, 7, 9, 12}
	BreedsPerSpecies[443] = {3, 5, 7, 9, 11, 12}
	BreedsPerSpecies[445] = {6, 7, 9, 10}
	BreedsPerSpecies[446] = {3, 4, 6, 9}
	BreedsPerSpecies[447] = {3, 5, 9, 11, 12}
	BreedsPerSpecies[448] = {3, 5, 7, 9, 11, 12}
	BreedsPerSpecies[449] = {3, 5, 11}
	BreedsPerSpecies[450] = {3, 6}
	BreedsPerSpecies[452] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[453] = {6, 7}
	BreedsPerSpecies[454] = {3, 5, 9, 11}
	BreedsPerSpecies[455] = {7, 8, 10}
	BreedsPerSpecies[456] = {3, 6, 7, 8}
	BreedsPerSpecies[457] = {6, 9}
	BreedsPerSpecies[458] = {3, 6}
	BreedsPerSpecies[459] = {3, 5, 8, 11}
	BreedsPerSpecies[460] = {3, 6, 9}
	BreedsPerSpecies[461] = {3}
	BreedsPerSpecies[463] = {6, 9}
	BreedsPerSpecies[464] = {3, 5, 9}
	BreedsPerSpecies[465] = {3, 4, 8}
	BreedsPerSpecies[466] = {3, 5, 7}
	BreedsPerSpecies[467] = {3, 6, 7, 9}
	BreedsPerSpecies[468] = {3, 6, 7, 9}
	BreedsPerSpecies[469] = {3, 4, 6, 7, 9}
	BreedsPerSpecies[470] = {3, 4, 7, 11}
	BreedsPerSpecies[471] = {3, 5, 6, 8, 9, 10}
	BreedsPerSpecies[472] = {3, 4, 5, 6, 7, 8, 10, 11}
	BreedsPerSpecies[473] = {3, 9}
	BreedsPerSpecies[474] = {5}
	BreedsPerSpecies[475] = {3, 12}
	BreedsPerSpecies[477] = {3, 11}
	BreedsPerSpecies[478] = {3, 9, 11, 12}
	BreedsPerSpecies[479] = {3, 11}
	BreedsPerSpecies[480] = {3, 6, 9}
	BreedsPerSpecies[482] = {3, 5}
	BreedsPerSpecies[483] = {3, 12}
	BreedsPerSpecies[484] = {3, 5, 8, 11}
	BreedsPerSpecies[485] = {6, 7, 9}
	BreedsPerSpecies[487] = {3, 5, 7, 10, 11, 12}
	BreedsPerSpecies[488] = {12}
	BreedsPerSpecies[489] = {4, 8, 10}
	BreedsPerSpecies[491] = {5, 8}
	BreedsPerSpecies[492] = {3, 6, 9}
	BreedsPerSpecies[493] = {3, 6, 7}
	BreedsPerSpecies[494] = {3, 6, 7}
	BreedsPerSpecies[495] = {3, 12}
	BreedsPerSpecies[496] = {3, 9, 12}
	BreedsPerSpecies[497] = {6, 7, 9, 12}
	BreedsPerSpecies[498] = {3, 8, 9}
	BreedsPerSpecies[499] = {7}
	BreedsPerSpecies[500] = {3, 4, 6, 7, 8, 10}
	BreedsPerSpecies[502] = {3, 12}
	BreedsPerSpecies[503] = {3, 5, 11}
	BreedsPerSpecies[504] = {3, 4, 10}
	BreedsPerSpecies[505] = {3, 5, 7, 11}
	BreedsPerSpecies[506] = {3, 6, 9, 11}
	BreedsPerSpecies[507] = {3, 9, 12}
	BreedsPerSpecies[508] = {3, 4, 7}
	BreedsPerSpecies[509] = {6, 7, 9}
	BreedsPerSpecies[511] = {3, 5, 11}
	BreedsPerSpecies[512] = {4, 6, 9, 12}
	BreedsPerSpecies[514] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12}
	BreedsPerSpecies[515] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12}
	BreedsPerSpecies[517] = {3, 8}
	BreedsPerSpecies[518] = {3, 6}
	BreedsPerSpecies[519] = {6, 7, 9}
	BreedsPerSpecies[521] = {10}
	BreedsPerSpecies[523] = {6, 9}
	BreedsPerSpecies[525] = {3, 5, 12}
	BreedsPerSpecies[528] = {9, 12}
	BreedsPerSpecies[529] = {4, 7}
	BreedsPerSpecies[530] = {3, 6, 7, 9}
	BreedsPerSpecies[532] = {4, 6}
	BreedsPerSpecies[534] = {3, 4, 5, 8, 10}
	BreedsPerSpecies[535] = {3, 9}
	BreedsPerSpecies[536] = {7, 9}
	BreedsPerSpecies[537] = {3, 4, 6, 7}
	BreedsPerSpecies[538] = {6, 8}
	BreedsPerSpecies[539] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[540] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[541] = {5, 6, 7, 9}
	BreedsPerSpecies[542] = {3, 12}
	BreedsPerSpecies[543] = {3, 5, 9}
	BreedsPerSpecies[544] = {5, 11, 12}
	BreedsPerSpecies[545] = {3, 5, 8}
	BreedsPerSpecies[546] = {6, 9, 12}
	BreedsPerSpecies[547] = {3, 5, 7, 9, 10, 11}
	BreedsPerSpecies[548] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12}
	BreedsPerSpecies[549] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[550] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[552] = {3, 4, 6, 7, 11}
	BreedsPerSpecies[553] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[554] = {3, 7, 9}
	BreedsPerSpecies[555] = {5, 6, 7, 9}
	BreedsPerSpecies[556] = {6, 9, 12}
	BreedsPerSpecies[557] = {4, 5, 7, 10, 11}
	BreedsPerSpecies[558] = {8}
	BreedsPerSpecies[559] = {4, 6, 7, 9}
	BreedsPerSpecies[560] = {3, 5, 10}
	BreedsPerSpecies[562] = {3, 5, 8}
	BreedsPerSpecies[564] = {3, 6, 12}
	BreedsPerSpecies[565] = {3, 12}
	BreedsPerSpecies[566] = {3, 9, 12}
	BreedsPerSpecies[567] = {5, 10}
	BreedsPerSpecies[568] = {3, 9}
	BreedsPerSpecies[569] = {3, 12}
	BreedsPerSpecies[570] = {3, 10}
	BreedsPerSpecies[571] = {3, 5}
	BreedsPerSpecies[572] = {4, 6}
	BreedsPerSpecies[573] = {3, 5, 10, 11}
	BreedsPerSpecies[626] = {4, 5, 7, 8, 10, 11}
	BreedsPerSpecies[627] = {7, 10}
	BreedsPerSpecies[628] = {3, 10}
	BreedsPerSpecies[629] = {3, 4, 7}
	BreedsPerSpecies[630] = {3, 5, 8, 10}
	BreedsPerSpecies[631] = {7, 9}
	BreedsPerSpecies[632] = {3, 10}
	BreedsPerSpecies[633] = {3, 7, 9, 12}
	BreedsPerSpecies[634] = {3, 9}
	BreedsPerSpecies[635] = {3, 8, 10}
	BreedsPerSpecies[637] = {3, 5, 11}
	BreedsPerSpecies[638] = {5, 6, 7, 9}
	BreedsPerSpecies[639] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[640] = {3, 5, 7, 9, 11, 12}
	BreedsPerSpecies[641] = {3, 5, 7, 9, 11, 12}
	BreedsPerSpecies[644] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[645] = {3, 8, 9}
	BreedsPerSpecies[646] = {3, 5, 11, 12}
	BreedsPerSpecies[647] = {3, 5, 8, 10, 11}
	BreedsPerSpecies[648] = {3, 6, 7, 12}
	BreedsPerSpecies[649] = {3, 7, 8}
	BreedsPerSpecies[650] = {8}
	BreedsPerSpecies[652] = {11}
	BreedsPerSpecies[665] = {11}
	BreedsPerSpecies[671] = {8}
	BreedsPerSpecies[675] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[677] = {3, 5, 8}
	BreedsPerSpecies[678] = {6, 9}
	BreedsPerSpecies[679] = {5, 11}
	BreedsPerSpecies[680] = {5, 11}
	BreedsPerSpecies[699] = {3, 9, 11, 12}
	BreedsPerSpecies[702] = {3, 5, 12}
	BreedsPerSpecies[703] = {3, 11}
	BreedsPerSpecies[706] = {3, 5, 8}
	BreedsPerSpecies[707] = {3, 5}
	BreedsPerSpecies[708] = {3, 5, 10, 11, 12}
	BreedsPerSpecies[709] = {3, 5, 11, 12}
	BreedsPerSpecies[710] = {3, 9, 11}
	BreedsPerSpecies[711] = {3, 5, 11}
	BreedsPerSpecies[712] = {3, 5, 11}
	BreedsPerSpecies[713] = {3, 9}
	BreedsPerSpecies[714] = {3, 4, 10, 11}
	BreedsPerSpecies[716] = {7, 9}
	BreedsPerSpecies[717] = {5, 6, 9, 12}
	BreedsPerSpecies[718] = {3, 8, 9}
	BreedsPerSpecies[722] = {3, 9, 10, 12}
	BreedsPerSpecies[723] = {3, 6, 9}
	BreedsPerSpecies[724] = {5, 10}
	BreedsPerSpecies[725] = {3, 11}
	BreedsPerSpecies[726] = {3, 5, 7}
	BreedsPerSpecies[727] = {3, 5, 8, 11, 12}
	BreedsPerSpecies[728] = {3, 5, 11, 12}
	BreedsPerSpecies[729] = {3, 5, 7, 9, 11, 12}
	BreedsPerSpecies[730] = {3, 5, 9, 11, 12}
	BreedsPerSpecies[731] = {7, 9}
	BreedsPerSpecies[732] = {8, 9}
	BreedsPerSpecies[733] = {3, 5, 11}
	BreedsPerSpecies[737] = {5, 8}
	BreedsPerSpecies[739] = {5, 8}
	BreedsPerSpecies[740] = {3, 9, 10, 11, 12}
	BreedsPerSpecies[741] = {3, 12}
	BreedsPerSpecies[742] = {3, 5}
	BreedsPerSpecies[743] = {3, 5, 12}
	BreedsPerSpecies[744] = {5, 6, 7, 9, 11, 12}
	BreedsPerSpecies[745] = {3, 9}
	BreedsPerSpecies[746] = {4, 6}
	BreedsPerSpecies[747] = {3, 9, 10, 12}
	BreedsPerSpecies[748] = {3, 5, 7, 8, 9, 10, 11, 12}
	BreedsPerSpecies[749] = {5, 11}
	BreedsPerSpecies[750] = {3, 5, 11}
	BreedsPerSpecies[751] = {3, 9, 11, 12}
	BreedsPerSpecies[752] = {3, 4, 12}
	BreedsPerSpecies[753] = {3, 9}
	BreedsPerSpecies[754] = {3, 5, 7, 8, 9, 11, 12}
	BreedsPerSpecies[755] = {8, 10}
	BreedsPerSpecies[756] = {3, 5, 9}
	BreedsPerSpecies[757] = {5}
	BreedsPerSpecies[758] = {8}
	BreedsPerSpecies[792] = {3, 12}
	BreedsPerSpecies[802] = {4}
	BreedsPerSpecies[817] = {7}
	BreedsPerSpecies[818] = {8}
	BreedsPerSpecies[819] = {5}
	BreedsPerSpecies[820] = {12}
	BreedsPerSpecies[821] = {11}
	BreedsPerSpecies[823] = {3, 5, 9, 12}
	BreedsPerSpecies[834] = {7}
	BreedsPerSpecies[835] = {5}
	BreedsPerSpecies[836] = {5}
	BreedsPerSpecies[837] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12}
	BreedsPerSpecies[838] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12}
	BreedsPerSpecies[844] = {5}
	BreedsPerSpecies[845] = {3, 8, 10}
	BreedsPerSpecies[846] = {5}
	BreedsPerSpecies[847] = {12}
	BreedsPerSpecies[848] = {3, 5, 9}
	BreedsPerSpecies[849] = {3}
	BreedsPerSpecies[850] = {3}
	BreedsPerSpecies[851] = {3, 5, 7}
	BreedsPerSpecies[855] = {3}
	BreedsPerSpecies[856] = {9, 12}
	BreedsPerSpecies[868] = {9}
	BreedsPerSpecies[903] = {10}
	BreedsPerSpecies[1013] = {3, 6, 9}
	BreedsPerSpecies[1039] = {6}
	BreedsPerSpecies[1040] = {6}
	BreedsPerSpecies[1042] = {8}
	BreedsPerSpecies[1061] = {5}
	BreedsPerSpecies[1062] = {3, 9, 10, 12}
	BreedsPerSpecies[1063] = {8}
	BreedsPerSpecies[1068] = {3, 5, 8, 10}
	BreedsPerSpecies[1073] = {12}
	BreedsPerSpecies[1117] = {3}
	BreedsPerSpecies[1124] = {8}
	BreedsPerSpecies[1125] = {3}
	BreedsPerSpecies[1126] = {7}
	BreedsPerSpecies[1127] = {8}
	BreedsPerSpecies[1128] = {3, 12}
	BreedsPerSpecies[1142] = {11}
	BreedsPerSpecies[1143] = {8}
	BreedsPerSpecies[1144] = {9}
	BreedsPerSpecies[1145] = {5}
	BreedsPerSpecies[1146] = {7}
	BreedsPerSpecies[1147] = {4}
	BreedsPerSpecies[1149] = {8}
	BreedsPerSpecies[1150] = {9}
	BreedsPerSpecies[1151] = {7}
	BreedsPerSpecies[1152] = {6}
	BreedsPerSpecies[1153] = {4}
	BreedsPerSpecies[1154] = {9}
	BreedsPerSpecies[1155] = {6}
	BreedsPerSpecies[1156] = {8}
	BreedsPerSpecies[1157] = {3, 12}
	BreedsPerSpecies[1158] = {12}
	BreedsPerSpecies[1159] = {12}
	BreedsPerSpecies[1160] = {8}
	BreedsPerSpecies[1161] = {4, 8, 10}
	BreedsPerSpecies[1162] = {5, 8}
	BreedsPerSpecies[1163] = {6, 7}
	BreedsPerSpecies[1164] = {3, 5, 11}
	BreedsPerSpecies[1165] = {4, 8, 10}
	BreedsPerSpecies[1166] = {4, 8, 10}
	BreedsPerSpecies[1167] = {4, 8, 10}
end